==> kubernetes-model-apps-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/ControllerRevisionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ControllerRevisionBuilder extends ControllerRevisionFluentImpl<ControllerRevisionBuilder> implements VisitableBuilder<ControllerRevision,ControllerRevisionBuilder> {

    ControllerRevisionFluent<?> fluent;
    Boolean validationEnabled;

    public ControllerRevisionBuilder() { 
        this(true);
    }


    public ControllerRevisionBuilder(Boolean validationEnabled) { 
        this(new ControllerRevision(), validationEnabled);
    }


    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent) { 
        this(fluent, true);
    }


    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ControllerRevision(), validationEnabled);
    }


    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance) { 
        this(fluent, instance, true);
    }


    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withData(instance.getData()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withRevision(instance.getRevision()); 
        this.validationEnabled = validationEnabled; 
    }


    public ControllerRevisionBuilder(ControllerRevision instance) { 
        this(instance,true);
    }


    public ControllerRevisionBuilder(ControllerRevision instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withData(instance.getData()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withRevision(instance.getRevision()); 
        this.validationEnabled = validationEnabled; 
    }


    public ControllerRevision build() {
        ControllerRevision buildable = new ControllerRevision(fluent.getApiVersion(),fluent.getData(),fluent.getKind(),fluent.getMetadata(),fluent.getRevision());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ControllerRevisionBuilder that = (ControllerRevisionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apps-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/ControllerRevisionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ControllerRevisionBuilder extends ControllerRevisionFluentImpl<ControllerRevisionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ControllerRevision,ControllerRevisionBuilder> {

    ControllerRevisionFluent<?> fluent;
    Boolean validationEnabled;

    public ControllerRevisionBuilder() {
        this(true);
    }

    public ControllerRevisionBuilder(Boolean validationEnabled) {
        this(new ControllerRevision(), validationEnabled);
    }

    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent) {
        this(fluent, true);
    }

    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ControllerRevision(), validationEnabled);
    }

    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance) {
        this(fluent, instance, true);
    }

    public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withData(instance.getData()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withRevision(instance.getRevision()); 
        this.validationEnabled = validationEnabled; 
    }

    public ControllerRevisionBuilder(ControllerRevision instance) {
        this(instance,true);
    }

    public ControllerRevisionBuilder(ControllerRevision instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withData(instance.getData()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withRevision(instance.getRevision()); 
        this.validationEnabled = validationEnabled; 
    }

    public ControllerRevision build() {
        ControllerRevision buildable = new ControllerRevision(fluent.getApiVersion(),fluent.getData(),fluent.getKind(),fluent.getMetadata(),fluent.getRevision());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ControllerRevisionBuilder that = (ControllerRevisionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
